@@ -601,13 +601,13 @@ import os, math, subprocess
 
     def test_break_up_import(self):
         self.assertEqual(
-            "import abc\nimport math\nimport subprocess\n",
+            "import abc\nimport subprocess\nimport math\n",
             autoflake.break_up_import("import abc, subprocess, math\n"),
         )
 
     def test_break_up_import_with_indentation(self):
         self.assertEqual(
-            "    import abc\n    import math\n    import subprocess\n",
+            "    import abc\n    import subprocess\n    import math\n",
             autoflake.break_up_import("    import abc, subprocess, math\n"),
         )
 
@@ -620,7 +620,7 @@ import os, math, subprocess
     def test_filter_from_import_no_remove(self):
         self.assertEqual(
             """\
-    from foo import abc, math, subprocess\n""",
+    from foo import abc, subprocess, math\n""",
             autoflake.filter_from_import(
                 "    from foo import abc, subprocess, math\n",
                 unused_module=[],
@@ -630,7 +630,7 @@ import os, math, subprocess
     def test_filter_from_import_remove_module(self):
         self.assertEqual(
             """\
-    from foo import math, subprocess\n""",
+    from foo import subprocess, math\n""",
             autoflake.filter_from_import(
                 "    from foo import abc, subprocess, math\n",
                 unused_module=["foo.abc"],
@@ -2360,7 +2360,6 @@ except ImportError:
                 prefix=".",
                 directory=directory,
             ) as inner_directory:
-
                 with temporary_file(
                     """\
 import re
@@ -2368,7 +2367,6 @@ import os
 """,
                     directory=inner_directory,
                 ):
-
                     output_file = io.StringIO()
                     autoflake._main(
                         argv=[
@@ -3387,6 +3385,32 @@ class ConfigFileTest(unittest.TestCase):
                 check=True,
             )
 
+    def test_config_option_toml(self):
+        with temporary_file(
+            suffix=".toml",
+            contents=(
+                "[tool.autoflake]\n"
+                "check = true\n"
+                'exclude = [\n  "build",\n  ".venv",\n]'
+            ),
+        ) as temp_config:
+            self.create_file("test_me.py")
+            files = [self.effective_path("test_me.py")]
+
+            args, success = autoflake.merge_configuration_file(
+                {
+                    "files": files,
+                    "config_file": temp_config,
+                },
+            )
+            assert success is True
+            assert args == self.with_defaults(
+                files=files,
+                config_file=temp_config,
+                check=True,
+                exclude="build,.venv",
+            )
+
     def test_load_false(self):
         self.create_file("test_me.py")
         self.create_file(
